<?php

class ControladorModulo{

	/*=============================================
	REGISTRO DE MODULO
	=============================================*/

	static public function ctrCrearModulo(){
		if(isset($_POST["nuevoNombre"])){
			if(preg_match('/[a-zA-Z0-9 ]/', $_POST["nuevoNombre"])){
				$tabla = "modulo";
				$datos = array("nombre" => strtoupper(trim($_POST["nuevoNombre"])));
				$respuesta = ModeloModulo::mdlIngresarModulo($tabla, $datos);
				if($respuesta == "ok"){
					echo '<script>
					swal({
						type: "success",
						title: "¡Modulo ha sido guardado correctamente!",
						showConfirmButton: true,
						confirmButtonText: "Cerrar"
					}).then(function(result){
						if(result.value){
							window.location = "permisos";
						}
					});
					</script>';
				}	
			}else{
				echo '<script>
					swal({
						type: "error",
						title: "¡Modulo no puede ir vacío o llevar caracteres especiales!",
						showConfirmButton: true,
						confirmButtonText: "Cerrar"
					}).then(function(result){
						if(result.value){
							window.location = "permisos";
						}
					});
				</script>';
			}
		}
	}

	/*=============================================
	MOSTRAR Modulo
	=============================================*/

	static public function ctrMostrarModulo($item, $valor){

		$tabla = "modulo";

		$respuesta = ModeloModulo::MdlMostrarModulo($tabla, $item, $valor);

		return $respuesta;
	}

	/*=============================================
	EDITAR USUARIO
	=============================================*/

	static public function ctrEditarModulo(){
		if(isset($_POST["editarNombre"])){
			if(preg_match('/[a-zA-Z0-9 ]/', $_POST["editarNombre"])){
				$tabla = "modulo";
				$datos = array("nombre" => strtoupper(trim($_POST["editarNombre"])),
								"id" => $_POST["idModulo"]);
				$respuesta = ModeloModulo::mdlEditarModulo($tabla, $datos);
				if($respuesta == "ok"){
					echo'<script>
					swal({
						  type: "success",
						  title: "Modulo ha sido editado correctamente",
						  showConfirmButton: true,
						  confirmButtonText: "Cerrar"
						  }).then(function(result){
									if (result.value) {
									window.location = "permisos";
									}
							})
					</script>';
				}
			}else{

				echo'<script>

					swal({
						  type: "error",
						  title: "¡El nombre no puede ir vacío o llevar caracteres especiales!",
						  showConfirmButton: true,
						  confirmButtonText: "Cerrar"
						  }).then(function(result){
							if (result.value) {
							window.location = "permisos";
							}
						})
			  	</script>';

			}

		}

	}

	/*=============================================
	BORRAR MODULO
	=============================================*/

	static public function ctrBorrarModulo(){
		if(isset($_GET["idModulo"])){
        $tabla ="modulo";
        $datos = $_GET["idModulo"];
        $respuesta = ModeloModulo::mdlDesactivarModulo($tabla, $datos);

        if($respuesta == "ok"){
            echo'<script>
            swal({
                  type: "success",
                  title: "Módulo ha sido desactivado correctamente",
                  showConfirmButton: true,
                  confirmButtonText: "Cerrar"
                  }).then(function(result){
                            if (result.value) {
                            window.location = "permisos";
                            }
                        })
            </script>';
        }       
    }

	}
}